@@ -1,13 +1,18 @@
 package Dist::Zilla::Plugin::VersionFromPrev::Finder::Git::LastVersion;
 BEGIN {
-  $Dist::Zilla::Plugin::VersionFromPrev::Finder::Git::LastVersion::VERSION = '0.04';
+  $Dist::Zilla::Plugin::VersionFromPrev::Finder::Git::LastVersion::AUTHORITY = 'cpan:AVAR';
+}
+BEGIN {
+  $Dist::Zilla::Plugin::VersionFromPrev::Finder::Git::LastVersion::VERSION = '0.05';
 }
 
 use 5.010;
 use Moose;
 
 sub last_version {
-    chomp(my $last = qx[ git tag -l | sort -nr | head -n1 ]);
+    chomp(my @tags = qx[ git tag -l ]);
+    my @sorted = sort { $b <=> $a } @tags;
+    my $last = $sorted[0];
 
     return $last eq '' ? undef : $last;
 }
